"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSignHookData = void 0;
const helpers_1 = require("../../helpers");
const sign_1 = require("../../url/helpers/sign");
const helpers_2 = require("../../url/helpers");
const index_1 = require("../../constants/index");
const shouldLogErrors = index_1.IS_DEVELOPMENT || index_1.IS_TEST;
const getSignHookData = (schema) => (search = window.location.search) => {
    const hook = (0, helpers_1.parseQueryParams)(search);
    const signHookData = (0, sign_1.parseSignUrl)(search);
    let isValid = false;
    try {
        sign_1.signBaseSchema.validateSync(hook, { strict: true });
        let valid = true;
        signHookData.txs.forEach((tx) => {
            try {
                schema.validateSync(tx, { strict: true });
            }
            catch ({ path, message }) {
                if (shouldLogErrors) {
                    console.error('hook tx format errors: ', {
                        [String(path)]: message
                    });
                }
                valid = false;
            }
        });
        isValid = valid;
    }
    catch ({ path, message }) {
        if (shouldLogErrors) {
            console.error('hook format errors: ', {
                [String(path)]: message
            });
        }
    }
    if (!isValid) {
        return null;
    }
    const { callbackUrl } = (0, helpers_2.sanitizeSignHookCallbackUrl)({
        callbackUrl: hook.callbackUrl
    });
    return {
        hookUrl: search,
        callbackUrl
    };
};
exports.getSignHookData = getSignHookData;
//# sourceMappingURL=getSignHookData.js.map